@@ -11,7 +11,11 @@ def checkDataSize(X, T, S):
     Tcard = np.unique(T).size
 
     # check data size
-    Scard = np.unique(S)
+    temp = np.unique(S)
+    Scard = list(temp)
+    Scard.append(np.max(temp)+1)
+    Scard = np.array(Scard)
+    
     [a, b] = np.histogram(S, Scard)
     #% all has to be fit data
     if min(a) < alpha * Xcard * Tcard:
